==> play-streams_3-3.0.1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"root","t":"root","d":"","k":"static","x":""},
{"l":"play/api/libs/streams.html#","e":false,"i":"","n":"play.api.libs.streams","t":"play.api.libs.streams","d":"","k":"package","x":""},
{"l":"play/api/libs/streams/Accumulator.html#","e":false,"i":"","n":"Accumulator","t":"Accumulator[-E, +A]","d":"play.api.libs.streams","k":"trait","x":""},
{"l":"play/api/libs/streams/Accumulator.html#asJava-0","e":false,"i":"","n":"asJava","t":"asJava: Accumulator[E, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#map-913","e":false,"i":"","n":"map","t":"map[B](f: A => B)(implicit executor: ExecutionContext): Accumulator[E, B]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#mapFuture-913","e":false,"i":"","n":"mapFuture","t":"mapFuture[B](f: A => Future[B])(implicit executor: ExecutionContext): Accumulator[E, B]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#recover-f3","e":false,"i":"","n":"recover","t":"recover[B >: A](pf: PartialFunction[Throwable, B])(implicit executor: ExecutionContext): Accumulator[E, B]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#recoverWith-f3","e":false,"i":"","n":"recoverWith","t":"recoverWith[B >: A](pf: PartialFunction[Throwable, Future[B]])(implicit executor: ExecutionContext): Accumulator[E, B]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#run-3b","e":false,"i":"","n":"run","t":"run(source: Source[E, _])(implicit materializer: Materializer): Future[A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#run-fffffbe9","e":false,"i":"","n":"run","t":"run()(implicit materializer: Materializer): Future[A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#run-fffffa76","e":false,"i":"","n":"run","t":"run(elem: E)(implicit materializer: Materializer): Future[A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#through-d29","e":false,"i":"","n":"through","t":"through[F](flow: Flow[F, E, _]): Accumulator[F, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#toSink-0","e":false,"i":"","n":"toSink","t":"toSink: Sink[E, Future[A]]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#~>:-d29","e":false,"i":"","n":"~>:","t":"~>:[F](flow: Flow[F, E, _]): Accumulator[F, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#~>:-3b","e":false,"i":"","n":"~>:","t":"~>:(source: Source[E, _])(implicit materializer: Materializer): Future[A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#","e":false,"i":"","n":"Accumulator","t":"Accumulator","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#apply-fffff3a5","e":false,"i":"","n":"apply","t":"apply[E, A](sink: Sink[E, Future[A]]): Accumulator[E, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#done-fffff315","e":false,"i":"","n":"done","t":"done[A](a: A): Accumulator[Any, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#done-a78","e":false,"i":"","n":"done","t":"done[A](a: Future[A]): Accumulator[Any, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#flatten-fffffb50","e":false,"i":"","n":"flatten","t":"flatten[E, A](future: Future[Accumulator[E, A]])(implicit materializer: Materializer): Accumulator[E, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#source-fffffc48","e":false,"i":"","n":"source","t":"source[E]: Accumulator[E, Source[E, _]]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#strict-ffffffd2","e":false,"i":"","n":"strict","t":"strict[E, A](strictHandler: Option[E] => Future[A], toSink: Sink[E, Future[A]]): Accumulator[E, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/ActorFlow$.html#","e":false,"i":"","n":"ActorFlow","t":"ActorFlow","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/ActorFlow$.html#actorRef-42e","e":false,"i":"","n":"actorRef","t":"actorRef[In, Out](props: ActorRef => Props, bufferSize: Int, overflowStrategy: OverflowStrategy)(implicit factory: ActorRefFactory, mat: Materializer): Flow[In, Out, _]","d":"play.api.libs.streams.ActorFlow","k":"def","x":""},
{"l":"play/api/libs/streams/GzipFlow$.html#","e":false,"i":"","n":"GzipFlow","t":"GzipFlow","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/GzipFlow$.html#gzip-e1","e":false,"i":"","n":"gzip","t":"gzip(bufferSize: Int, compressionLevel: Int): Flow[ByteString, ByteString, _]","d":"play.api.libs.streams.GzipFlow","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#","e":false,"i":"","n":"PekkoStreams","t":"PekkoStreams","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#bypassWith-d3","e":false,"i":"","n":"bypassWith","t":"bypassWith[In, FlowIn, Out](splitter: In => Either[FlowIn, Out]): Flow[FlowIn, Out, _] => Flow[In, Out, _]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#bypassWith-fffffaf5","e":false,"i":"","n":"bypassWith","t":"bypassWith[In, FlowIn, Out](splitter: Flow[In, Either[FlowIn, Out], _], mergeStrategy: Graph[UniformFanInShape[Out, Out], _]): Flow[FlowIn, Out, _] => Flow[In, Out, _]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#ignoreAfterCancellation-b30","e":false,"i":"","n":"ignoreAfterCancellation","t":"ignoreAfterCancellation[T]: Flow[T, T, Future[Done]]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#ignoreAfterFinish-b30","e":false,"i":"","n":"ignoreAfterFinish","t":"ignoreAfterFinish[T]: Flow[T, T, _]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#onlyFirstCanFinishMerge-d74","e":false,"i":"","n":"onlyFirstCanFinishMerge","t":"onlyFirstCanFinishMerge[T](inputPorts: Int): Graph[UniformFanInShape[T, T], NotUsed]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#","e":false,"i":"","n":"Probes","t":"Probes","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/Probes$.html#flowProbe-fffff866","e":false,"i":"","n":"flowProbe","t":"flowProbe[T](name: String, messageLogger: T => String): Flow[T, T, _]","d":"play.api.libs.streams.Probes","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#processorProbe-137","e":false,"i":"","n":"processorProbe","t":"processorProbe[In, Out](name: String, processor: Processor[In, Out], inLogger: In => String, outLogger: Out => String): Processor[In, Out]","d":"play.api.libs.streams.Probes","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#publisherProbe-4b5","e":false,"i":"","n":"publisherProbe","t":"publisherProbe[T](name: String, publisher: Publisher[T], messageLogger: T => String): Publisher[T]","d":"play.api.libs.streams.Probes","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#subscriberProbe-13f","e":false,"i":"","n":"subscriberProbe","t":"subscriberProbe[T](name: String, subscriber: Subscriber[_ >: T], messageLogger: T => String, start: Long): Subscriber[T]","d":"play.api.libs.streams.Probes","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#subscriptionProbe-fffffbdf","e":false,"i":"","n":"subscriptionProbe","t":"subscriptionProbe(name: String, subscription: Subscription, start: Long): Subscription","d":"play.api.libs.streams.Probes","k":"def","x":""}];

==> play-streams_3-3.0.9-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"root","t":"root","d":"","k":"static","x":""},
{"l":"play/api/libs/streams.html#","e":false,"i":"","n":"play.api.libs.streams","t":"play.api.libs.streams","d":"","k":"package","x":""},
{"l":"play/api/libs/streams/Accumulator.html#","e":false,"i":"","n":"Accumulator","t":"Accumulator[-E, +A]","d":"play.api.libs.streams","k":"trait","x":""},
{"l":"play/api/libs/streams/Accumulator.html#asJava-0","e":false,"i":"","n":"asJava","t":"asJava: Accumulator[E, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#map-913","e":false,"i":"","n":"map","t":"map[B](f: A => B)(implicit executor: ExecutionContext): Accumulator[E, B]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#mapFuture-913","e":false,"i":"","n":"mapFuture","t":"mapFuture[B](f: A => Future[B])(implicit executor: ExecutionContext): Accumulator[E, B]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#recover-f3","e":false,"i":"","n":"recover","t":"recover[B >: A](pf: PartialFunction[Throwable, B])(implicit executor: ExecutionContext): Accumulator[E, B]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#recoverWith-f3","e":false,"i":"","n":"recoverWith","t":"recoverWith[B >: A](pf: PartialFunction[Throwable, Future[B]])(implicit executor: ExecutionContext): Accumulator[E, B]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#run-3b","e":false,"i":"","n":"run","t":"run(source: Source[E, _])(implicit materializer: Materializer): Future[A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#run-fffffbe9","e":false,"i":"","n":"run","t":"run()(implicit materializer: Materializer): Future[A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#run-fffffa76","e":false,"i":"","n":"run","t":"run(elem: E)(implicit materializer: Materializer): Future[A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#through-d29","e":false,"i":"","n":"through","t":"through[F](flow: Flow[F, E, _]): Accumulator[F, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#toSink-0","e":false,"i":"","n":"toSink","t":"toSink: Sink[E, Future[A]]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#~>:-d29","e":false,"i":"","n":"~>:","t":"~>:[F](flow: Flow[F, E, _]): Accumulator[F, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator.html#~>:-3b","e":false,"i":"","n":"~>:","t":"~>:(source: Source[E, _])(implicit materializer: Materializer): Future[A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#","e":false,"i":"","n":"Accumulator","t":"Accumulator","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#apply-fffff3a5","e":false,"i":"","n":"apply","t":"apply[E, A](sink: Sink[E, Future[A]]): Accumulator[E, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#done-fffff315","e":false,"i":"","n":"done","t":"done[A](a: A): Accumulator[Any, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#done-a78","e":false,"i":"","n":"done","t":"done[A](a: Future[A]): Accumulator[Any, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#flatten-fffffb50","e":false,"i":"","n":"flatten","t":"flatten[E, A](future: Future[Accumulator[E, A]])(implicit materializer: Materializer): Accumulator[E, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#source-fffffc48","e":false,"i":"","n":"source","t":"source[E]: Accumulator[E, Source[E, _]]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/Accumulator$.html#strict-ffffffd2","e":false,"i":"","n":"strict","t":"strict[E, A](strictHandler: (Option[E]) => Future[A], toSink: Sink[E, Future[A]]): Accumulator[E, A]","d":"play.api.libs.streams.Accumulator","k":"def","x":""},
{"l":"play/api/libs/streams/ActorFlow$.html#","e":false,"i":"","n":"ActorFlow","t":"ActorFlow","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/ActorFlow$.html#actorRef-42e","e":false,"i":"","n":"actorRef","t":"actorRef[In, Out](props: ActorRef => Props, bufferSize: Int, overflowStrategy: OverflowStrategy)(implicit factory: ActorRefFactory, mat: Materializer): Flow[In, Out, _]","d":"play.api.libs.streams.ActorFlow","k":"def","x":""},
{"l":"play/api/libs/streams/GzipFlow$.html#","e":false,"i":"","n":"GzipFlow","t":"GzipFlow","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/GzipFlow$.html#gzip-e1","e":false,"i":"","n":"gzip","t":"gzip(bufferSize: Int, compressionLevel: Int): Flow[ByteString, ByteString, _]","d":"play.api.libs.streams.GzipFlow","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#","e":false,"i":"","n":"PekkoStreams","t":"PekkoStreams","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#bypassWith-d3","e":false,"i":"","n":"bypassWith","t":"bypassWith[In, FlowIn, Out](splitter: In => Either[FlowIn, Out]): (Flow[FlowIn, Out, _]) => Flow[In, Out, _]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#bypassWith-fffffaf5","e":false,"i":"","n":"bypassWith","t":"bypassWith[In, FlowIn, Out](splitter: Flow[In, Either[FlowIn, Out], _], mergeStrategy: Graph[UniformFanInShape[Out, Out], _]): (Flow[FlowIn, Out, _]) => Flow[In, Out, _]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#ignoreAfterCancellation-b30","e":false,"i":"","n":"ignoreAfterCancellation","t":"ignoreAfterCancellation[T]: Flow[T, T, Future[Done]]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#ignoreAfterFinish-b30","e":false,"i":"","n":"ignoreAfterFinish","t":"ignoreAfterFinish[T]: Flow[T, T, _]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/PekkoStreams$.html#onlyFirstCanFinishMerge-d74","e":false,"i":"","n":"onlyFirstCanFinishMerge","t":"onlyFirstCanFinishMerge[T](inputPorts: Int): Graph[UniformFanInShape[T, T], NotUsed]","d":"play.api.libs.streams.PekkoStreams","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#","e":false,"i":"","n":"Probes","t":"Probes","d":"play.api.libs.streams","k":"object","x":""},
{"l":"play/api/libs/streams/Probes$.html#flowProbe-fffff866","e":false,"i":"","n":"flowProbe","t":"flowProbe[T](name: String, messageLogger: T => String): Flow[T, T, _]","d":"play.api.libs.streams.Probes","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#processorProbe-137","e":false,"i":"","n":"processorProbe","t":"processorProbe[In, Out](name: String, processor: Processor[In, Out], inLogger: In => String, outLogger: Out => String): Processor[In, Out]","d":"play.api.libs.streams.Probes","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#publisherProbe-4b5","e":false,"i":"","n":"publisherProbe","t":"publisherProbe[T](name: String, publisher: Publisher[T], messageLogger: T => String): Publisher[T]","d":"play.api.libs.streams.Probes","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#subscriberProbe-13f","e":false,"i":"","n":"subscriberProbe","t":"subscriberProbe[T](name: String, subscriber: Subscriber[_ >: T], messageLogger: T => String, start: Long): Subscriber[T]","d":"play.api.libs.streams.Probes","k":"def","x":""},
{"l":"play/api/libs/streams/Probes$.html#subscriptionProbe-fffffbdf","e":false,"i":"","n":"subscriptionProbe","t":"subscriptionProbe(name: String, subscription: Subscription, start: Long): Subscription","d":"play.api.libs.streams.Probes","k":"def","x":""}];
